{% if breadcrumbs|length > 1 %}
<div class="container">
  <ul class="breadcrumb" itemprop="breadcrumb">
    {% for breadcrumb in breadcrumbs %}
    {% if loop.last %}
    <li class="active">
      {{ breadcrumb.text|safe }}
    </li>
    {% else %}
    <li>
      <a href="{{ breadcrumb.url }}"
         class="navtrail">
        {{ breadcrumb.text|safe }}
      </a>
    </li>
    {% endif %}
    {% endfor %}
  </ul>
</div>
{% endif %}
