{#
# This file is part of Invenio.
# Copyright (C) 2015 CERN.
#
# Invenio is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.#}

{%- extends "invenio_theme/settings/base.html" -%}

{% block settings_menu %}
<div class="col-sm-3 col-md-3 col-pad-left-0">
    <div class="panel-group">
      <div class="panel panel-default">
        <div class="panel-heading"><strong>{{ _('Settings') }}</strong></div>
        <ul class="list-group">
        {%- for item in current_menu.submenu('settings').children if item.visible %}
            {%- for subitem in item.children %}
                <a href="{{ subitem.url }}" class="list-group-item{% if subitem.active %} active{% endif %}">{{ subitem.text|safe }}</a>
            {%- endfor %}
        {%- endfor %}
        </ul>
      </div>
    </div>
</div>
{% endblock %}
