{% extends config.THEME_ERROR_TEMPLATE %}

{% block message %}
  <h1><i class="fa fa-flash"></i> {{_('Unauthorized')}}</h1>
  <p>{{_('You need to be authenticated to view this page.')}}</p>
{% endblock message %}
