// Footer
$footer-height: 60px;
$footer-background-color1: #f0f0f0;
$footer-background-color2: lighten($footer-background-color1, 4%);

html {
  position: relative;
  min-height: 100%;
}

body {
  margin-bottom: $footer-height;
}

#footer {
  position: absolute;
  bottom: 0;
  width: 100%;
  height: $footer-height;
  background-color: $footer-background-color2;
  color: darken($footer-background-color2, 40%);
}

#footer > .menu-wrapper {
  background-color: $footer-background-color1;
  color: darken($footer-background-color1, 40%);
  a {
    color: darken($footer-background-color1, 40%);
  }
}

#footer .row {
  padding-top: 10px;
}
