{%- if config['ACCOUNTS'] %}
{%- if not current_user.is_authenticated() %}
<form class="navbar-form navbar-right">
  <a href=" {{url_for_security('login')}}" class="btn btn-default"><i class="fa fa-sign-in"></i> {{_('Log in')}}</a>
  {% if security.registerable %}<a href=" {{url_for_security('register')}}" type="submit" class="btn btn-default btn-warning"><i class="fa fa-edit"></i> {{_('Sign up')}}</a>{% endif %}
</form>
{%- else %}
<div class="navbar-form navbar-right">
<a href=" {{url_for_security('logout')}}" class="btn btn-default"><i class="fa fa-sign-out"></i> {{_('Log out')}}</a>
</div>
{%- endif %}
{%- endif %}
