<header>
  {%- block navbar %}
  <nav class="navbar navbar-inverse navbar-static-top">
    <div class="container">
      {%- block navbar_header %}
      <div class="navbar-header">
        <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar" aria-expanded="false" aria-controls="navbar">
          <span class="sr-only">{{_('Toggle navigation')}}</span>
          <span class="icon-bar"></span>
          <span class="icon-bar"></span>
          <span class="icon-bar"></span>
        </button>
        {% block brand %}<a class="navbar-brand" href="/">{{_(config.THEME_SITENAME)}}</a>{% endblock %}
      </div>
      {%- endblock navbar_header %}
      {%- block navbar_inner %}
      <div id="navbar" class="navbar-collapse collapse">
        <ul class="nav navbar-nav">
          {%- for item in current_menu.submenu('main').children|sort(attribute='order') if item.visible recursive %}
          {%- if item.children -%}
          <li class="dropdown{{ ' active' if item.active else ''}}">
            <a class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false" href="{{ item.url }}">{{ item.text|safe }} <b class="caret"></b></a>
            <ul class="dropdown-menu">{{ loop(item.children|sort(attribute='order')) }}</ul>
          </li>
          {%- else -%}
            <li{{ ' class="active"'|safe if item.active and loop.depth == 1 else '' }}><a href="{{ item.url }}">{{ item.text|safe }}</a></li>
          {%- endif %}
          {%- endfor %}
        </ul>
        {%- block navbar_right %}
{%- include "invenio_theme/header_login.html" %}
        {%- endblock navbar_right %}
      </div>
      {%- endblock navbar_inner %}
    </div>
  </nav>
  {%- endblock navbar %}
  {%- block breadcrumbs %}
{%- include "invenio_theme/breadcrumbs.html" %}
  {%- endblock breadcrumbs %}
</header>
