{% extends config.THEME_ERROR_TEMPLATE %}

{% block message %}
  <h1><i class="fa fa-flash"></i> {{_('Page not found')}}</h1>
  <p>{{_('The page you where looking for could not be found.')}}</p>
{% endblock message %}

